Re-exports
pub use connection::in_channel::InChannels;pub use connection::information_packet::Content;pub use connection::out_channel::OutChannels;pub use graph::error::DagrsError;pub use graph::error::DagrsResult;pub use graph::error::ErrorCode;pub use graph::error::ErrorContext;pub use utils::checkpoint::Checkpoint;pub use utils::checkpoint::CheckpointConfig;pub use utils::checkpoint::CheckpointId;pub use utils::checkpoint::CheckpointStore;pub use utils::checkpoint::FileCheckpointStore;pub use utils::checkpoint::MemoryCheckpointStore;pub use utils::checkpoint::NodeExecStatus;pub use utils::checkpoint::NodeState;pub use utils::checkpoint::StoredOutputKind;pub use utils::env::EnvVar;pub use utils::output::Output;pub use async_trait;pub use tokio;pub use node::*;pub use graph::*;
Modules
Macros
- dependencies
- The
dependencies!macro allows users to specify all task dependencies in an easy-to-understand way. It returnsResult<dagrs::Graph, dagrs::DagrsError>so build errors are not silently ignored.
Attribute Macros
- auto_
node - [
auto_node] is a macro that may be used when customizing nodes. It can only be marked on named struct or unit struct.